package Bio::Tools::Motif::Pattern;

use Bio::Root::Root;
use Carp;

use strict;

our @ISA = qw(Bio::Root::Root);
our $VERSION = '0.01';

sub new {
  my ($class, @args) = @_;
  my $self = $class->SUPER::new(@args);

  # Get the parameters we've been passed.
  my ($id,$loc,$regexp,$comment) =
    $self->_rearrange([qw(MOTIFID LOCALIZATION REGEXP COMMENT)], @args);

  $self->{localization} = $loc;
  $self->{motif_id}     = $id;
  $self->{regexp}       = $regexp;
  $self->{comment}      = $comment;

  return $self;
}

sub motif_id {
  my $self = shift;

  return (@_) ? $self->{motif_id} = shift : $self->{motif_id};
}

sub localization {
  my $self = shift;

  return (@_) ? $self->{localization} = shift : $self->{localization};
}

sub regexp {
  my $self = shift;

  return (@_) ? $self->{regexp} = shift : $self->{regexp};
}

sub comment {
  my $self = shift;

  return (@_) ? $self->{comment} = shift : $self->{comment};
}

=head1 NAME

  Bio::Tools::Motif::Pattern - Represents a pattern used by the
  Bio::Tools::Motif module.

=head1 SYNOPSIS

  use Bio::Tools::Motif::Pattern;

  # Create a new object.
  $m = new Bio::Tools::Motif::Pattern(-motifid => 'P07110',
                                      -localization => 'OuterMembrane',
                                      -regexp => '(GG.G.D.*){4}',
                                      -comment => 'FIMBRIAL_USHER Pattern');

  # Accessor methods.
  $val = $m->motif_id();
  $val = $m->localization();
  $val = $m->regexp();
  $val = $m->comment();

=head1 AUTHOR

Cory Spencer <cspencer@sfu.ca>

=head1 SEE ALSO

  Bio::Tools::Motif

=head1 ACKNOWLEGEMENTS

Thanks go out to Fiona Brinkman, Jennifer Gardy and the other members of the
Simon Fraser University Brinkman laboratory.

=cut

1;
