package Bio::Tools::PSort::Module::Motif;

use Bio::Tools::PSort::Module::AnalysisI;
use Bio::Tools::PSort::Report::Result;
use Bio::Tools::Motif;

use vars qw(@ISA);
@ISA = qw(Bio::Tools::PSort::Module::AnalysisI);

use strict;

sub new {
  my ($class, @args) = @_;
  my $self = $class->SUPER::new(@args);

  my ($db) = $self->_rearrange([qw(DATABASE)], @args);

  $self->{motif} = new Bio::Tools::Motif(-database => $db) ||
    $self->throw("Couldn't create new Bio::Tools::Motif object");

  return $self;
}

sub run {
  my ($self, $seq) = @_;

  my @res = map {
    my $detail = "matched " . $_->motif_id . ": " . $_->comment;
    new Bio::Tools::PSort::Report::Result(-details => [ $detail ],
					  -score   => 0,
					  -loc     => $_->localization);
  } $self->{motif}->match($seq);

  @res ? @res : new Bio::Tools::PSort::Report::Result(-loc => 'Unknown',
						      -details => ['No motifs found']);
}

1;

=head1 NAME

=head1 SYNOPSIS

=head1 DESCRIPTION

=head1 CONSTRUCTOR

=head1 METHODS

=head1 SEE ALSO

=head1 AUTHOR

 Cory Spencer <cspencer@sfu.ca>

=cut

__END__
