package Bio::Tools::PSort::Module::OMPMotif;

use Bio::Tools::PSort::Module::AnalysisI;
use Bio::Tools::PSort::Report::Result;
use Bio::Tools::Motif;

use vars qw(@ISA);
@ISA = qw(Bio::Tools::PSort::Module::AnalysisI);

use strict;

sub new {
  my ($class, @args) = @_;
  my $self = $class->SUPER::new(@args);

  my ($db, $cutoff) = $self->_rearrange([qw(DATABASE CUTOFF)], @args);

  $self->{motif} = new Bio::Tools::Motif(-database => $db) ||
    $self->throw("Couldn't create new Bio::Tools::Motif object");

  # Set the number of patterns needed to make a classification, or default
  # to three if a value wasn't provided.
  $self->{cutoff} = defined($cutoff) ? ($cutoff + 0) : 3;

  return $self;
}

sub run {
  my ($self, $seq) = @_;

  my @matches = $self->{motif}->match($seq);
  if(@matches >= $self->{cutoff}) {
    my $detail = "matched " . @matches . " rules";
    $detail .= " (" . join(', ', map { $_->motif_id } @matches) . ")";

    return new Bio::Tools::PSort::Report::Result(-details => [ $detail ],
						 -score   => 0,
						 -loc     => 'OuterMembrane');
  }

  return new Bio::Tools::PSort::Report::Result(-loc => 'Unknown',
					       -details => ['No motifs found']);
}

1;

=head1 NAME

=head1 SYNOPSIS

=head1 DESCRIPTION

=head1 CONSTRUCTOR

=head1 METHODS

=head1 SEE ALSO

=head1 AUTHOR

 Cory Spencer <cspencer@sfu.ca>

=cut

__END__
