package Bio::Tools::PSort::Module::Rules;

use Bio::Tools::PSort::Module::OutputI;
use Bio::Tools::PSort::Report::Result;
use Data::Dumper;

use vars qw(@ISA);
@ISA = qw(Bio::Tools::PSort::Module::OutputI);

use strict;

sub new {
  my ($class, @args) = @_;
  my $self = $class->SUPER::new(@args);

  return $self;
}

sub run {
  my ($self, $seq, %res) = @_;
  my ($hassig);

  # Return HMMTOP prediction if one was made.
  if(defined($res{HMMTOP}) && (my ($hmmtop) = @{$res{HMMTOP}})) {
    $hassig = 1 if(join('', $hmmtop->details) =~ /signal peptide/i);
    return $hmmtop if($hmmtop->localization ne "Unknown");
  }

  # Return Motif prediction if one was made.
  if(defined($res{Motif}) && (my ($motif) = @{$res{Motif}})) {
    return $motif if($motif->localization ne "Unknown");
  }

  # Return OMPMotif prediction if one was made.
  if(defined($res{OMPMotif}) && (my ($omotif) = @{$res{OMPMotif}})) {
    return $omotif if($omotif->localization ne "Unknown");
  }

  # Return SCLBlast prediction if one was made.
  if(defined($res{SCLBlast}) && (my ($scl) = @{$res{SCLBlast}})) {
    return $scl if($scl->localization ne "Unknown");
  }

  # Check to see if the Signal module found a signal peptide.
  if(defined($res{Signal}) && (my ($signal) = @{$res{Signal}})) {
    $hassig = 1 if(join('', $signal->details) =~ /signal peptide/i);
  }

  # Return SubLoc prediction only if Cytoplasmic was predicted.
  if(defined($res{SubLoc}) && (my ($subloc) = @{$res{SubLoc}})) {
    return $subloc if(($subloc->localization eq "Cytoplasmic") && ! $hassig);
  }

  return new Bio::Tools::PSort::Report::Result(-loc => 'Unknown');
}

1;
