package Bio::Tools::PSort::Module::SCLBlast;

use Bio::Tools::PSort::Report::Result;
use Bio::Tools::PSort::Constants qw(:all);
use Bio::Tools::PSort::Module::AnalysisI;
use Bio::Tools::Run::SCLBlast;
use Bio::SearchIO;

use vars qw(@ISA);
use strict;

@ISA = qw(Bio::Tools::PSort::Module::AnalysisI);

sub new {
  my ($class, @args) = @_;
  my $self = $class->SUPER::new(@args);

  my ($db) = $self->_rearrange([qw(DATABASE)], @args);

  # Create a new Bio::Tools::Run::SBLBlast instance.
  $self->{sclblast} = new Bio::Tools::Run::SCLBlast(-database => $db);

  return $self;
}

sub run {
  my ($self, $seq) = @_;
  my @res;

  # Ensure that we received a Bio::Seq object.
  $self->throw("Didn't receive a Bio::Seq")
    if((! ref($seq)) || (! $seq->isa('Bio::Seq')));

  if(my $brep = $self->{sclblast}->blast($seq)) {
    my $hit = $brep->next_hit;
    if($hit) {
      my @locs = $hit->localization;

      my $r = new Bio::Tools::PSort::Report::Result();
      $r->localization(\@locs);
      $r->details(["matched " . $hit->description]);
      push(@res, $r);
    }
  }

  @res ? @res : new Bio::Tools::PSort::Report::Result(-loc => 'Unknown',
						      -details => ['No matches against database']);
}

1;
