package Bio::Tools::PSort::Module::SubLoc;

use Bio::Tools::PSort::Constants qw(:all);
use Bio::Tools::PSort::Module::AnalysisI;
use Bio::Tools::PSort::Report::Result;
use Bio::Tools::SubLoc;

use vars qw(@ISA);
use strict;

@ISA = qw(Bio::Tools::PSort::Module::AnalysisI);

my %LOCMAP = (Cytoplasmic   => CYTOPLASM,
	      InnerMembrane => INNERMEMBRANE,
	      Periplasmic   => PERIPLASM,
	      OuterMembrane => OUTERMEMBRANE,
	      Extracellular => EXTRACELLULAR);

sub new {
  my ($class, @args) = @_;
  my $self = $class->SUPER::new(@args);

  my ($model) = $self->_rearrange([qw(MODEL)], @args);

  $self->{subloc} = new Bio::Tools::SubLoc(-model => $model) ||
    $self->throw("Couldn't create new Bio::Tools::SubLoc object");

  return $self;
}

sub run {
  my ($self, $seq) = @_;

  $self->throw("Not a Bio::Seq object")
    if((! ref($seq)) && (! $seq->isa("Bio::Seq")));

  my $loc = $self->{subloc}->classify($seq);

  return new Bio::Tools::PSort::Report::Result(-details => [ ],
					       -score   => 0,
					       -loc     => $loc);
}

1;
