=head1 NAME

Bio::Tools::PSort::ModuleI - an interface class that all PSort modules should derive
implement.

=head1 SYNOPSIS

    package Bio::Tools::PSort::Module::Foo;

    use Bio::Tools::PSort::Module;

    use vars qw(@ISA);
    @ISA = qw(Bio::Tools::PSort::Module;

    ...
    ...

    1;

=head1 DESCRIPTION

The module object contains functionality common to all PSort modules.  This
class is not intended to be instantiated on it's own, it only provides 
functionality common to all PSort modules.


=head1 METHODS

    $result = $module->run($seq);

The run method must be overridden in all derived classes.  run() should accept
a Bio::Tools::Seq object, and perform whatever analysis the module provides on the
sequence, returning a bio::PSort::Scort object upon completion.

=head1 SEE ALSO

Bio::Tools::PSort, Bio::Tools::PSort::Pathway, Bio::Tools::PSort::Score

=head1 AUTHOR

 Cory Spencer <cspencer@sfu.ca>

=cut

package Bio::Tools::PSort::ModuleI;

use Bio::Root::Root;

use vars qw(@ISA);
@ISA = qw(Bio::Root::Root);

use strict;

sub module_name {
  my $self = shift;

  $self->throw_not_implemented;
}

sub module_description {
  my $self = shift;

  $self->throw_not_implemented();
}

sub module_type  {
  my $self = shift;

 SWITCH: {
    $self->isa("Bio::Tools::PSort::Module::InputI") && return 'input';
    $self->isa("Bio::Tools::PSort::Module::AnalysisI") && return 'analysis';
    $self->isa("Bio::Tools::PSort::Module::OutputI") && return 'output';

    return 'unknown';
  }
}

sub run {
  my $self = shift;

  $self->throw_not_implemented();
}

sub _run {
  my ($self, $rpt) = @_;
  my $res;

  $res = $self->run($rpt);

  return $res;
}

1;
