package Bio::Tools::PSort::Report::Formatter;

use Bio::Root::Root;

use vars qw/@ISA/;
use strict;

@ISA = qw(Bio::Root::Root);

sub new {
  my ($class, @args) = @_;
  my $self = $class->SUPER::new(@args);

  return $self;
}

sub format {
  my ($self, $format, $args, @reps) = @_;

  $self->install($format, $args);

  return $self->{modules}->{$format}->format(@reps);
}

sub install {
  my ($self, $mod, $args) = @_;


  # If we didn't receive the name of a module to load, throw an exception.
  $self->throw("No module specified") if(! $mod);

  # If the module has already been loaded, return right away.
  return if(exists($self->{modules}->{$mod}));

  $args = { } if(! defined($args));

  # Attempt to load the specified module.
  eval("require Bio::Tools::PSort::Report::Formatter::$mod");
  $self->throw("Failed to load module $mod: $@") if($@);

  # Attempt to instantiate the module, throw exception on failure.
  my $module = eval { "Bio::Tools::PSort::Report::Formatter::$mod"->new(%{$args}) };
  $self->throw("Failed to instantiate module $mod: $@") if($@);

  # Store the module for later use.
  $self->{modules}->{$mod} = $module;

  return 1;
}

1;
