package Bio::Tools::PSort::Report::Formatter::normal;

use Bio::Root::Root;

use vars qw(@ISA);
use strict;

@ISA = qw(Bio::Root::Root);

sub new {
  my ($class, @args) = @_;
  my $self = bless({ }, $class);

  ($self->{cutoff}) = $self->_rearrange(['CUTOFF'], @args);
  $self->{cutoff} = 0.75 if(! $self->{cutoff});

  return $self;
}

sub format {
  my ($self, @reps) = @_;
  my $output;

  if(@reps) {
    for my $rep (@reps) {
      my $seq = $rep->seq();
      my $ismult;

      $output .= "SeqID: " . $seq->display_id . " " . $seq->desc . "\n";
      $output .= "  Analysis Report:\n";

      for my $mod ($rep->get_modules("analysis")) {
	my @res = $rep->get_result("analysis", $mod);
	for my $res (@res) {
	  my $details = join(', ', $res->details) || "No details";
	  my @locs = $res->localization;

	  # Flag the result if it has multiple localization sites.
	  $ismult = 1 if(@locs > 1);

	  # Totally nastly hack, but Jenn wanted it so I'm blaming her.
	  @locs = "Non-Cytoplasmic"
	    if(($locs[0] ne "Unknown") && ($mod eq "Signal"));
	  $output .= sprintf("    %-18s%-30s[%s]\n", $mod, join(', ', @locs),
			     $details);
	}
      }

      $output .= "  Localization Scores:\n";
      my @res = $rep->get_result("output", "Bayesian");
      for my $res (@res) {
	$output .= sprintf("    %-17s %-.2f\n", $res->localization, ($res->score * 10));
      }

      $output .= "  Final Prediction:\n";
      my $topscore = shift(@res);

      if($topscore->score >= $self->{cutoff}) {
	my $loc = $topscore->localization;
	my $scr = $topscore->score * 10;

	$loc .= " (This protein may have multiple localiation sites.)" if($ismult);
	$output .= sprintf("    %-17s %-.2f\n", $loc, $scr);
      } else {
	$output .= "    Unknown\n";
      }

      $output .= "\n" . ("-" x 79) . "\n\n";
    }
  }

  return $output;
}

1;
