package Bio::Tools::PSort::Report::Formatter::terse;

use Bio::Root::Root;

use vars qw(@ISA);
use strict;

@ISA = qw(Bio::Root::Root);

sub new {
  my ($class, @args) = @_;
  my $self = bless({ }, $class);

  ($self->{cutoff}) = $self->_rearrange(['CUTOFF'], @args);
  $self->{cutoff} = 0.75 if(! $self->{cutoff});

  return $self;
}

sub format {
  my ($self, @reps) = @_;
  my $output;

  if(@reps) {
    my @mods = $reps[0]->get_modules("output");

    # Create the report header.
    $output = "SeqID";
    $output .= "\t$_" . "_Localization\t$_" . "_Score" for(@mods);
    $output .= "\n";

    # Add a new line for every sequence.
    for my $rep (@reps) {
      # Make sure we got the right kind of object.
      $self->throw("Not a Bio::Tools::PSort::Report")
	if((! ref($rep)) && (ref($rep) ne "Bio::Tools::PSort::Report"));

      # Get the sequence we're about to format the report for.
      $output .= $rep->seq->display_id() . " " . $rep->seq->desc();

      for (@mods) {
	my ($res) = $rep->get_result("output", $_);

	my $loc = ($res->score >= $self->{cutoff}) ? $res->localization : "Unknown";

	$output .= "\t$loc\t" . sprintf("%4.2f", ($res->score * 10));
      }

      $output .= "\n";
    }
  }

  return $output;
}

1;
