package Bio::Tools::PSort::XMLRPC::Client;

use RPC::XML::Client;
use RPC::XML;

use Bio::Tools::PSort::Report::Result;
use Bio::Tools::PSort::Report;
use Bio::Root::Root;

use strict;

use vars qw(@ISA);
@ISA = qw(Bio::Root::Root);

sub new {
  my ($class, @args) = @_;
  my $self = $class->SUPER::new(@args);

  # Get any of the parameters passed to the constructor.
  my ($server,$method) = $self->_rearrange([qw(SERVER METHOD)], @args);

  # Set some default values if they weren't received in the constructor.
  $self->{server} = $server || 'http://localhost/RPC';
  $self->{method} = $method || 'psort.classify';

  # Create a new XML-RPC client.
  $self->{client} = RPC::XML::Client->new($self->{server});

  return $self;
}

sub classify {
  my ($self, $seq, $path) = @_;
  my ($req, $rep, $res);

  # Create the structure of the request we're going to send.
  $req = { seq  => $seq->seq,
	   path => { input    => $path->{input}    || 'all',
		     analysis => $path->{analysis} || 'all',
		     output   => $path->{output}   || 'all' }};

  $res = $self->{client}->send_request($self->{method}, $req);

  # Check to see if we received a reference to an object from the send_request.
  # (If we didn't, then there was a client side send error - check parameters
  # passed to the RPC::XML::Client constructor.)
  if(ref($res)) {
    if(! $res->is_fault) {
      my $res = $res->value;
      my $rep = new Bio::Tools::PSort::Report(-seq => $seq);
      for my $path (keys(%{$res})) {
	my %res = ( );
	for my $mod (keys(%{$res->{$path}})) {
	  my @res;
	  for(@{$res->{$path}->{$mod}}) {
	    my @locs = split(',', $_->{localization});
	    push(@res, new Bio::Tools::PSort::Report::Result(
		         -loc => \@locs,
			 -score => $_->{score} || 0,
                         -details => $_->{details}));
	  }

	  $res{$mod} = \@res;
	}
	$rep->add_results($path, %res);
      }

      return $rep;
    } else {
      # Fault was returned, throw an exception.
      $self->throw("XML-RPC fault: " . $res->string);
    }
  } else {
    $self->throw("XML-RPC client side send error");
  }
}

1;
